@@ -15,7 +15,6 @@
 #    under the License.
 
 import abc
-import collections
 import functools
 import logging
 import pprint
@@ -23,7 +22,6 @@ import pprint
 import alembic
 import alembic.autogenerate
 import alembic.migration
-import pkg_resources as pkg
 import sqlalchemy
 import sqlalchemy.exc
 import sqlalchemy.sql.expression as expr
@@ -79,7 +77,8 @@ class WalkVersionsMixin(object, metaclass=abc.ABCMeta):
 
     """
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def INIT_VERSION(self):
         """Initial version of a migration repository.
 
@@ -89,7 +88,8 @@ class WalkVersionsMixin(object, metaclass=abc.ABCMeta):
         """
         pass
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def REPOSITORY(self):
         """Allows basic manipulation with migration repository.
 
@@ -97,7 +97,8 @@ class WalkVersionsMixin(object, metaclass=abc.ABCMeta):
         """
         pass
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def migration_api(self):
         """Provides API for upgrading, downgrading and version manipulations.
 
@@ -105,7 +106,8 @@ class WalkVersionsMixin(object, metaclass=abc.ABCMeta):
         """
         pass
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def migrate_engine(self):
         """Provides engine instance.
 
@@ -122,30 +124,6 @@ class WalkVersionsMixin(object, metaclass=abc.ABCMeta):
         """
         pass
 
-    def _walk_versions(self, snake_walk=False, downgrade=True):
-        """Check if migration upgrades and downgrades successfully.
-
-        DEPRECATED: this function is deprecated and will be removed from
-        oslo.db in a few releases. Please use walk_versions() method instead.
-        """
-        self.walk_versions(snake_walk, downgrade)
-
-    def _migrate_down(self, version, with_data=False):
-        """Migrate down to a previous version of the db.
-
-        DEPRECATED: this function is deprecated and will be removed from
-        oslo.db in a few releases. Please use migrate_down() method instead.
-        """
-        return self.migrate_down(version, with_data)
-
-    def _migrate_up(self, version, with_data=False):
-        """Migrate up to a new version of the db.
-
-        DEPRECATED: this function is deprecated and will be removed from
-        oslo.db in a few releases. Please use migrate_up() method instead.
-        """
-        self.migrate_up(version, with_data)
-
     def walk_versions(self, snake_walk=False, downgrade=True):
         """Check if migration upgrades and downgrades successfully.
 
@@ -479,77 +457,6 @@ class ModelsMigrationsSync(object, metaclass=abc.ABCMeta):
                 isinstance(meta_def.arg, expr.False_) and insp_def == "0"
             )
 
-    FKInfo = collections.namedtuple('fk_info', ['constrained_columns',
-                                                'referred_table',
-                                                'referred_columns'])
-
-    def check_foreign_keys(self, metadata, bind):
-        """Compare foreign keys between model and db table.
-
-        :returns: a list that contains information about:
-
-         * should be a new key added or removed existing,
-         * name of that key,
-         * source table,
-         * referred table,
-         * constrained columns,
-         * referred columns
-
-         Output::
-
-             [('drop_key',
-               'testtbl_fk_check_fkey',
-               'testtbl',
-               fk_info(constrained_columns=('fk_check',),
-                       referred_table='table',
-                       referred_columns=('fk_check',)))]
-
-        DEPRECATED: this function is deprecated and will be removed from
-        oslo.db in a few releases. Alembic autogenerate.compare_metadata()
-        now includes foreign key comparison directly.
-
-        """
-
-        diff = []
-        insp = sqlalchemy.engine.reflection.Inspector.from_engine(bind)
-        # Get all tables from db
-        db_tables = insp.get_table_names()
-        # Get all tables from models
-        model_tables = metadata.tables
-        for table in db_tables:
-            if table not in model_tables:
-                continue
-            # Get all necessary information about key of current table from db
-            fk_db = dict((self._get_fk_info_from_db(i), i['name'])
-                         for i in insp.get_foreign_keys(table))
-            fk_db_set = set(fk_db.keys())
-            # Get all necessary information about key of current table from
-            # models
-            fk_models = dict((self._get_fk_info_from_model(fk), fk)
-                             for fk in model_tables[table].foreign_keys)
-            fk_models_set = set(fk_models.keys())
-            for key in (fk_db_set - fk_models_set):
-                diff.append(('drop_key', fk_db[key], table, key))
-                LOG.info(("Detected removed foreign key %(fk)r on "
-                          "table %(table)r"), {'fk': fk_db[key],
-                                               'table': table})
-            for key in (fk_models_set - fk_db_set):
-                diff.append(('add_key', fk_models[key], table, key))
-                LOG.info((
-                    "Detected added foreign key for column %(fk)r on table "
-                    "%(table)r"), {'fk': fk_models[key].column.name,
-                                   'table': table})
-        return diff
-
-    def _get_fk_info_from_db(self, fk):
-        return self.FKInfo(tuple(fk['constrained_columns']),
-                           fk['referred_table'],
-                           tuple(fk['referred_columns']))
-
-    def _get_fk_info_from_model(self, fk):
-        return self.FKInfo((fk.parent.name,), fk.column.table.name,
-                           (fk.column.name,))
-
     def filter_metadata_diff(self, diff):
         """Filter changes before assert in test_models_sync().
 
@@ -557,22 +464,12 @@ class ModelsMigrationsSync(object, metaclass=abc.ABCMeta):
         filtering is performed, changes are returned as is.
 
         :param diff: a list of differences (see `compare_metadata()` docs for
-                     details on format)
+            details on format)
         :returns: a list of differences
-
         """
-
         return diff
 
     def test_models_sync(self):
-        # recent versions of sqlalchemy and alembic are needed for running of
-        # this test, but we already have them in requirements
-        try:
-            pkg.require('sqlalchemy>=0.8.4', 'alembic>=0.6.2')
-        except (pkg.VersionConflict, pkg.DistributionNotFound) as e:
-            self.skipTest('sqlalchemy>=0.8.4 and alembic>=0.6.3 are required'
-                          ' for running of this test: %s' % e)
-
         # drop all objects after a test run
         engine = self.get_engine()
         backend = provision.Backend(engine.name, engine.url)
